pub struct Database {
    pool: Pool<Postgres>,
}
A database connection pool holder, with functions for inserting and getting ActivityPub objects to and from.

Fields

pool: Pool<Postgres>

Implementations

Creates a new connection pool and run migrations to bring the database up to speed.

Inserts the object into the database, or do nothing if it has already been inserted.

Inserts the item into the collection. Both ids must refer to objects that have been previously inserted with Database::insert.

Returns the object with the id. If the object is an “OrderedCollection”, page will be used to provide the specific “CollectionPage”, if provided.

Adds the activity with the given id to the delivery queue, to be delivered to the given inbox.

Waits until the next time there’s deliveries to be delivered.

Implementation details

Returns either when the “activitypub_inbox_delivery” channel is notified (i.e. when a new delivery is added to the db), or when the earliest “next_delivery_time_utc” is reached, whichever is first.

Returns a list of (inbox, activity to send to inbox) tuples that are due to be sent now, and marks the rows as having attempted a delivery at the time of calling this function.

Marks deliveries as failed, to be retried. The slice should contain tuples containing the (inbox_url, activity_id).

Marks deliveries as successful, clearing them out of the delivery queue. The slice should contain tuples containing the (inbox_url, activity_id).